<?php
/*
	* functions.php
*/

/**
 * Load plugin textdomain.
 *
 * @since 1.0.0
 */
add_action( 'plugins_loaded', 'pm_sbox_load_textdomain' );
function pm_sbox_load_textdomain() {
  load_plugin_textdomain( 'pm-suggestion-box', false, dirname( plugin_basename( __DIR__ ) ) . '/languages' );
}

/**
 * Flush rewrite rules for custom post type archive on single activation
 * http://wordpress.stackexchange.com/questions/118690/flush-rewrite-rules-not-working-on-plugin-activation
 *
 * @since    0.0.1
 */
function pm_sbox_suggestion_install() {
	// Register post type first
	$labels = array(
		'name'               => PM_SBOX_PLUGIN_NAME,
		'singular_name'      => PM_SBOX_PLUGIN_NAME,
		'menu_name'          => PM_SBOX_PLUGIN_NAME,
		'name_admin_bar'     => PM_SBOX_PLUGIN_NAME,
		'add_new'            => __( 'Add New', 'suggestion_box', 'pm-suggestion-box' ),
		'add_new_item'       => __( 'Add New ', 'pm-suggestion-box' ).PM_SBOX_PLUGIN_NAME,
		'new_item'           => __( 'New', 'pm-suggestion-box' ),
		'edit_item'          => __( 'Edit', 'pm-suggestion-box' ),
		'view_item'          => __( 'View', 'pm-suggestion-box' ),
		'all_items'          => __( 'All', 'pm-suggestion-box' ),
		'search_items'       => __( 'Search', 'pm-suggestion-box' ),
		'parent_item_colon'  => __( 'Parent', 'pm-suggestion-box' ),
		'not_found'          => __( 'Not found.', 'pm-suggestion-box' ),
		'not_found_in_trash' => __( 'None found in Trash.', 'pm-suggestion-box' )
	);

	$args = array(
		'labels'             => $labels,
		'public'             => true,
		'publicly_queryable' => true,
		'exclude_from_search' => false,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'query_var'          => false,

		'capability_type'    => 'post',
		'has_archive'        => false,
		'hierarchical'       => false,
		'menu_position'      => null,
		'supports'           => array( 'title', 'editor', 'author', 'thumbnail')
	);

	register_post_type( 'suggestion_box', $args );

	// Now you can flush
		flush_rewrite_rules();

		global $wpdb;

		$table_name = $wpdb->prefix . 'pm_sbox';

		$sql = "CREATE TABLE $table_name (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			postid bigint(20) NOT NULL,
			vote int(9) NOT NULL,
			time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
			ip varchar(20) NOT NULL,
			UNIQUE KEY id (id)
		);";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
}

function pm_sbox_suggestion_deactivate() {

}

add_action( 'init', 'pm_sbox_post_type_init' );
/**
 * Register a Suggestion Box post type.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_post_type
 */
function pm_sbox_post_type_init() {
	$add_new = 
	$labels = array(
		'name'               => PM_SBOX_PLUGIN_NAME,
		'singular_name'      => PM_SBOX_PLUGIN_NAME,
		'menu_name'          => PM_SBOX_PLUGIN_NAME,
		'name_admin_bar'     => PM_SBOX_PLUGIN_NAME,
		'add_new'            => __( 'Add New', 'suggestion_box', 'pm-suggestion-box' ),
		'add_new_item'       => __( 'Add New ', 'pm-suggestion-box' ).PM_SBOX_PLUGIN_NAME,
		'new_item'           => __( 'New', 'pm-suggestion-box' ),
		'edit_item'          => __( 'Edit', 'pm-suggestion-box' ),
		'view_item'          => __( 'View', 'pm-suggestion-box' ),
		'all_items'          => __( 'All', 'pm-suggestion-box' ),
		'search_items'       => __( 'Search', 'pm-suggestion-box' ),
		'parent_item_colon'  => __( 'Parent', 'pm-suggestion-box' ),
		'not_found'          => __( 'Not found.', 'pm-suggestion-box' ),
		'not_found_in_trash' => __( 'None found in Trash.', 'pm-suggestion-box' )
	);

	$args = array(
		'labels'             => $labels,
		'public'             => true,
		'publicly_queryable' => true,
		'exclude_from_search' => false,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'query_var'          => false,

		'capability_type'    => 'post',
		'has_archive'        => false,
		'hierarchical'       => false,
		'menu_position'      => null,
		'supports'           => array( 'title', 'editor', 'author', 'thumbnail')
	);

	register_post_type( 'suggestion_box', $args );

	// Register shorcode-ui - Lynette
	if( !function_exists( 'shortcode_ui_register_for_shortcode' ) ) {
		add_action( 'admin_notices', function() {
			if( current_user_can( 'activate_plugins' ) )
				echo '<div class="error message"><p>Shortcode UI must be active.</p></div>';
		});
	}
	shortcode_ui_register_for_shortcode(
		'pm-suggestions-create',
		array(
			// Display label
			'label' => PM_SBOX_PLUGIN_NAME.': Add form'
			)
		);
	shortcode_ui_register_for_shortcode(
		'pm-suggestions',
		array(
			// Display label
			'label' => 'Display list',
			// Icon for shortcode
			'listItemImage' => 'dashicons-lightbulb',
			// Shortcode attributes
			'attrs' => array(
				array(
					'label' => 'No. of suggestions',
					'attr' => 'limit',
					'type' => 'number'
				),
			)
		)
		);

	// Initialize editor button
	$editor_buttons = new Pm_Sbox_Editor();
	$editor_buttons->init_plugin();
}


/*
	* pm_sbox_suggestion_vote
*/

function pm_sbox_suggestion_vote($args) {
	global $wpdb;
	$table_name = $wpdb->prefix . 'pm_sbox';
	
	$defaults = array(
		'postid'	=>	'',
		'time'	=> '',
		'vote'	=> '',
		'ip'	=>  ''
	);

	$args = wp_parse_args( $args, $defaults );

	$add = $wpdb->query(
		$wpdb->prepare(
			"INSERT INTO {$table_name} SET
				`postid`    = '%s',
				`time`    = NOW(),
				`vote`    = '%s',
				`ip`    = '%s'
			;",
			absint( $args['pid'] ),
			absint( $args['vote'] ),
			filter_var( $args['uid'], FILTER_VALIDATE_IP )
		)
	);
}

/*
	* pm_sbox_ips
*/

function pm_sbox_ips($ip) {
	global $wpdb;
	$table_name = $wpdb->prefix . 'pm_sbox';
	$array = array();
	$results = $wpdb->get_results( $wpdb->prepare( 
		"
			SELECT DISTINCT postid, vote, ip
			FROM {$table_name} 
			WHERE ip LIKE '%s'
		", 
		$ip
	),OBJECT );
	foreach($results as $result) {
		$array[$result->postid] = $result->vote;
	}
	return $array;
}



/*
	*pm_sbox_suggestion
*/

add_action( 'wp_ajax_pm_sbox_suggestion', 'pm_sbox_suggestion_callback' );
add_action( 'wp_ajax_nopriv_pm_sbox_suggestion', 'pm_sbox_suggestion_callback' );
		
function pm_sbox_suggestion_callback() {
	global $wpdb; // this is how you get access to the database
	$pm_status_like = '_pm_sbox_like';
	$pm_status_dislike = '_pm_sbox_dislike';
	$pm_sbox_meta = '_pm_sbox_meta';
	$current_total_votes = 0;
	$allow_guest = get_option(PM_SBOX_SETTINGS_OPTION.'_guest');
	$limit_day = get_option(PM_SBOX_SETTINGS_OPTION.'_limit_day');
	$current_ip = pm_get_the_user_ip();
	$vote = 0;
		
	if ( is_user_logged_in() ) {
		$uid = get_current_user_id();
	} elseif ( !is_user_logged_in() && $allow_guest ) {
		$uid = $current_ip;
	}
	
	$user_votes = (is_array(get_user_meta($uid,$pm_sbox_meta,true)) ? get_user_meta($uid,$pm_sbox_meta,true) : array());
	$count = '';
	$pid = intval( $_POST['pid'] );
	$psStatus = $_POST['status'];
	
	$end_type = get_post_meta($pid, '_pm_end_type', true);
	$end_total_vote = get_post_meta($pid, '_pm_sbox_end_total_vote', true);
	
	//Update Post Meta Based on Status
	if($psStatus == 'like'){
		$pm_cur_likes = (get_post_meta($pid,$pm_status_like,true) ? intval(get_post_meta($pid,$pm_status_like,true)): 0);
		$pm_cur_dislikes = (get_post_meta($pid,$pm_status_dislike,true) ? intval(get_post_meta($pid,$pm_status_dislike,true)) : 0);
		$current_total_votes = $pm_cur_likes + $pm_cur_dislikes + 1;
		
		update_post_meta($pid,$pm_status_like,$pm_cur_likes+1);
		$count = $pm_cur_likes;
		//Add pid to User Votes
		$user_votes[$pid] = 1;
		$vote = 1;
	} elseif($psStatus == 'dislike'){
		$pm_cur_likes = (get_post_meta($pid,$pm_status_like,true) ? intval(get_post_meta($pid,$pm_status_like,true)): 0);
		$pm_cur_dislikes = (get_post_meta($pid,$pm_status_dislike,true) ? intval(get_post_meta($pid,$pm_status_dislike,true)) : 0);
		$current_total_votes = $pm_cur_likes + $pm_cur_dislikes + 1;
		
		update_post_meta($pid,$pm_status_dislike,$pm_cur_dislikes+1);
		$count = $pm_cur_dislikes;
		//Add pid to User Votes
		$user_votes[$pid] = 0;
		$vote = 0;
	}
	if ( !is_user_logged_in() && $allow_guest ) {
		$args = array( 'pid' => $pid, 'uid' => $uid, 'vote' => $vote);
		pm_sbox_suggestion_vote( $args );
	} elseif ( is_user_logged_in() ) {
		update_user_meta($uid,$pm_sbox_meta,$user_votes);
	}
	
	
	if($end_type == 'total_vote' && $current_total_votes >= $end_total_vote ) {
		update_post_meta($pid,'_pm_end_voting','yes');
	}
	
	//
	
	print 'success';
	die(); // this is required to return a proper result
}

/*
	* Expire Vote is Date is Reached
*/

function pm_sbox_expire_suggestion($post_id) {
	$allow_auto_end = (get_option(PM_SBOX_SETTINGS_OPTION.'_auto_end') ? true : false);
	$end_type = (get_post_meta($post_id, '_pm_end_type', true) ? get_post_meta($post_id, '_pm_end_type', true) : 'date');
	if($allow_auto_end && $end_type == 'date'): 
		$end_date = new DateTime(get_post_meta($post_id, '_pm_sbox_end_date', true));
		$date_now = new DateTime(current_time( 'mysql' ));
		if($date_now >= $end_date):
			update_post_meta($post_id,'_pm_end_voting','yes');
		else:
			//Do function not end
		endif;
	endif;
	
}

/*
	* pm_get_the_user_ip
*/

function pm_get_the_user_ip() {
	if ( ! empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {
		//check ip from share internet
		$ip = $_SERVER['HTTP_CLIENT_IP'];
	} elseif ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
		//to check ip is pass from proxy
		$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
	} else {
		$ip = $_SERVER['REMOTE_ADDR'];
	}
	return $ip;
}

/*
	* pm_sbox_votes_columns_head
	* Register Columns on suggestion_box list
*/

function pm_sbox_votes_columns_head($defaults) {
	$defaults['pm_sbox_user_votes'] = esc_html(__('Likes | Dislikes', 'pm-suggestion-box'));
	return $defaults;
}

function pm_sbox_votes_columns_content($column_name, $pid) {
	$output ="<div class='suggestion_box_wrapper'>";
	if ($column_name == 'pm_sbox_user_votes') {
		$pm_status_like = '_pm_sbox_like';
		$pm_status_dislike = '_pm_sbox_dislike';
		$pm_cur_likes = (get_post_meta($pid,$pm_status_like,true) ? intval(get_post_meta($pid,$pm_status_like,true)): 0);
		$pm_cur_dislikes = (get_post_meta($pid,$pm_status_dislike,true) ? intval(get_post_meta($pid,$pm_status_dislike,true)) : 0);
		$output .= '<ul><li>';
		$output .= "<span class='pm_sbox_btn_style done pm_sbox_like'>{$pm_cur_likes}</span> | ";
		$output .= "<span class='pm_sbox_btn_style done pm_sbox_dislike'> {$pm_cur_dislikes}</span> ";
		$output .= '</li></ul>';
    }
	$output .= "</div>";
	$output .= pm_sbox_style();
	print $output;
}

add_filter('manage_suggestion_box_posts_columns', 'pm_sbox_votes_columns_head');
add_action('manage_suggestion_box_posts_custom_column', 'pm_sbox_votes_columns_content', 10, 2);


add_filter( 'the_content', 'pm_sbox_content_voting', 20 );


/**
 * Add Voting at End of Content
 *
 * @uses is_single()
 */
function pm_sbox_content_voting( $content ) {

    if ( is_single() ):
		global $post;
		$end_voting_result = get_post_meta($post->ID, '_pm_end_voting_result', true);
		$atts = array('pid' => $post->ID);
        $content .= sprintf("%s",pm_sbox_shortcode( $atts ) );
		if($end_voting_result) {
		$pid = $post->ID;
		$pm_status_like = '_pm_sbox_like';
		$pm_status_dislike = '_pm_sbox_dislike';
		$pm_cur_likes = (get_post_meta($pid,$pm_status_like,true) ? intval(get_post_meta($pid,$pm_status_like,true)): 0);
		$pm_cur_dislikes = (get_post_meta($pid,$pm_status_dislike,true) ? intval(get_post_meta($pid,$pm_status_dislike,true)) : 0);
		$result = '';
		if($pm_cur_likes == $pm_cur_dislikes){
		$result = 'Tie';
		} else if($pm_cur_likes > $pm_cur_dislikes){
		$result = 'Like';
		} else if($pm_cur_likes < $pm_cur_dislikes){
		$result = 'Dislike';
		}
		$content .= sprintf(__("Voting has Ended and result is:  <strong class='pm_end_result'>%s</strong> with <strong class='pm_end_result_likes'>%s</strong> Likes and <strong class='pm_end_result_dislikes'>%s</strong> Dislikes.", 'pm-suggestion-box'), $result,$pm_cur_likes,$pm_cur_dislikes );
		}
	endif;
    // Returns the content.
    return $content;
}


/**
 * Add Color Picker input
 *
 * @uses is_single()
 */
function pm_sbox_color_picker_input() {
	$color_array = array();
	
	$pm_like_bg = (get_option(PM_SBOX_SETTINGS_OPTION.'_like_bg') ? get_option(PM_SBOX_SETTINGS_OPTION.'_like_bg') : '#8AC007');
	$pm_like_fg = (get_option(PM_SBOX_SETTINGS_OPTION.'_like_fg') ? get_option(PM_SBOX_SETTINGS_OPTION.'_like_fg') : '#FFFFFF');
	$pm_like_bgh = (get_option(PM_SBOX_SETTINGS_OPTION.'_like_bg_hover') ? get_option(PM_SBOX_SETTINGS_OPTION.'_like_bg_hover') : '#28C007');
	$pm_like_fgh = (get_option(PM_SBOX_SETTINGS_OPTION.'_like_fg_hover') ? get_option(PM_SBOX_SETTINGS_OPTION.'_like_fg_hover') : '#FFFFFF');
	
	$pm_dislike_bg = (get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_bg') ? get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_bg') : '#d9534f');
	$pm_dislike_fg = (get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_fg') ? get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_fg') : '#FFFFFF');
	$pm_dislike_bgh = (get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_bg_hover') ? get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_bg_hover') : '#D31E1E');
	$pm_dislike_fgh = (get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_fg_hover') ? get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_fg_hover') : '#FFFFFF');
	
	$color_array['_like_bg'] = array('val' => $pm_like_bg, 'label' => __('Like bg', 'pm-suggestion-box'));
	$color_array['_like_fg'] = array('val' => $pm_like_fg, 'label' => __('Like text', 'pm-suggestion-box'));
	$color_array['_like_bg_hover'] = array('val' => $pm_like_bgh, 'label' => __('Like bg hover', 'pm-suggestion-box'));
	$color_array['_like_fg_hover'] = array('val' => $pm_like_fgh, 'label' => __('Like text hover', 'pm-suggestion-box'));
	
	$color_array['_dislike_bg'] = array('val' => $pm_dislike_bg, 'label' => __('Dislike bg', 'pm-suggestion-box'));
	$color_array['_dislike_fg'] = array('val' => $pm_dislike_fg, 'label' => __('Dislike text', 'pm-suggestion-box'));
	$color_array['_dislike_bg_hover'] = array('val' => $pm_dislike_bgh, 'label' => __('Dislike bg hover', 'pm-suggestion-box'));
	$color_array['_dislike_fg_hover'] = array('val' => $pm_dislike_fgh, 'label' => __('Dislike text hover', 'pm-suggestion-box'));
	
	return $color_array;
}

/*
	* pm_sbox_style
*/

function pm_sbox_style() { 
$pm_like_bg = (get_option(PM_SBOX_SETTINGS_OPTION.'_like_bg') ? get_option(PM_SBOX_SETTINGS_OPTION.'_like_bg') : '#8AC007');
$pm_like_fg = (get_option(PM_SBOX_SETTINGS_OPTION.'_like_fg') ? get_option(PM_SBOX_SETTINGS_OPTION.'_like_fg') : '#FFFFFF');
$pm_like_bgh = (get_option(PM_SBOX_SETTINGS_OPTION.'_like_bg_hover') ? get_option(PM_SBOX_SETTINGS_OPTION.'_like_bg_hover') : '#28C007');
$pm_like_fgh = (get_option(PM_SBOX_SETTINGS_OPTION.'_like_fg_hover') ? get_option(PM_SBOX_SETTINGS_OPTION.'_like_fg_hover') : '#FFFFFF');

$pm_dislike_bg = (get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_bg') ? get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_bg') : '#d9534f');
$pm_dislike_fg = (get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_fg') ? get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_fg') : '#FFFFFF');
$pm_dislike_bgh = (get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_bg_hover') ? get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_bg_hover') : '#D31E1E');
$pm_dislike_fgh = (get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_fg_hover') ? get_option(PM_SBOX_SETTINGS_OPTION.'_dislike_fg_hover') : '#FFFFFF');

$output = '';
$output .= "<style>
	.suggestion_box_wrapper .pm_sbox_like {
		background: {$pm_like_bg};
		color: {$pm_like_fg};
	}
	
	.suggestion_box_wrapper .pm_sbox_like.available:hover {
		background: {$pm_like_bgh};
		color: {$pm_like_fgh};
	}
	
	.suggestion_box_wrapper  .pm_sbox_dislike {
		background: {$pm_dislike_bg};
		color: {$pm_dislike_fg};
	}
	
	.suggestion_box_wrapper  .pm_sbox_dislike.available:hover {
		background: {$pm_dislike_bgh};
		color: {$pm_dislike_fgh};
	}
	
</style>";
return $output;
}