<?php 
add_action( 'add_meta_boxes', 'pm_sbox_add_custom_box' );
function pm_sbox_add_custom_box() {
	add_meta_box(
		'pm_sbox_mbox',
		__( PM_SBOX_PLUGIN_NAME.' Settings' , 'pm-suggestion-box' ),
		'pm_sbox_inner_custom_box',
		'suggestion_box', 'side' , 'core'
	);
}

function pm_sbox_inner_custom_box( $post ) {
	
	wp_nonce_field( plugin_basename( __FILE__ ), 'pm_sbox_noncename' );
	//End Suggestion when Expired by Date
	pm_sbox_expire_suggestion($post->ID);
	$allow_auto_end = (get_option(PM_SBOX_SETTINGS_OPTION.'_auto_end') ? true : false);
	$end_voting = get_post_meta($post->ID, '_pm_end_voting', true);
	$end_voting_result = get_post_meta($post->ID, '_pm_end_voting_result', true);
	$end_type = (get_post_meta($post->ID, '_pm_end_type', true) ? get_post_meta($post->ID, '_pm_end_type', true) : 'date');
	$end_date = get_post_meta($post->ID, '_pm_sbox_end_date', true);
	$end_total_vote = get_post_meta($post->ID, '_pm_sbox_end_total_vote', true);

	?>
	<div id="suggestion_box_post_meta">
	  <div>
		<input <?php print ($end_voting ? 'checked' : ''); ?> type="checkbox" id="custom_pm_sbox-end-<?php echo $post->ID; ?>" class="custom_pm_sbox_enable" name="_pm_end_voting" value="yes" />
		<label for="custom_pm_sbox-end-<?php echo $post->ID; ?>"><?php _e( 'End Voting', 'pm-suggestion-box' ); ?></label>
		<br /><span style="font-size: 10px;"><i><?php esc_html(_e( 'If checked, voting will be ended.', 'pm-suggestion-box' )); ?></i></span>
	  </div>
	  <?php if($allow_auto_end): ?>
			<div id="pm_end_type_wrapper"><p class="description"><?php esc_html(_e( 'End Method', 'pm-suggestion-box' )); ?></p>
			<input <?php print ($end_type == 'date' ? 'checked' : ''); ?> type="radio" name="_pm_end_type" value="date" checked id="pm_end_type_date" class="pm_end_type"> <label for="pm_end_type_date"><?php esc_html(_e( 'Date', 'pm-suggestion-box' )); ?></label><br />
			<input <?php print ($end_type == 'total_vote' ? 'checked' : ''); ?> type="radio" name="_pm_end_type" value="total_vote" id="pm_end_type_total_vote"  class="pm_end_type"> <label for="pm_end_type_total_vote"><?php esc_html(_e( 'Total Vote', 'pm-suggestion-box' )); ?></label>
			</div>
			
			<div id="pm_end_type_date_wrapper" class="pm_end_type_wrapper" <?php print ($end_type == 'date' ? '' : 'style="display: none;"'); ?>><label for="pm_sbox_end_date"><?php esc_html(_e( 'End Date', 'pm-suggestion-box' )); ?></label><br />
			<input type="text" name="_pm_sbox_end_date" id="pm_sbox_end_date" placeholder="mm/dd/yyyy" value="<?php print $end_date; ?>" /></div>
			
			<div id="pm_end_type_total_vote_wrapper" class="pm_end_type_wrapper" <?php print ($end_type == 'total_vote' ? '' : 'style="display: none;"'); ?>><label for="pm_sbox_end_total_vote"><?php esc_html(_e( 'Total vote reached', 'pm-suggestion-box' )); ?></label><br />
			<input type="number" name="_pm_sbox_end_total_vote" id="pm_sbox_end_total_vote" placeholder="Enter number" min="0" pattern="[0-9]*" value="<?php print $end_total_vote; ?>" /></div>
		<?php endif; ?>
		<div>
			<input <?php print ($end_voting_result ? 'checked' : ''); ?> type="checkbox" id="custom_pm_sbox-end-result-<?php echo $post->ID; ?>" class="custom_pm_sbox_enable" name="_pm_end_voting_result" value="yes" />
			<label for="custom_pm_sbox-end-result-<?php echo $post->ID; ?>"><?php _e( 'Show Result when Voting is Ended', 'pm-suggestion-box' ); ?></label>
			<br /><span style="font-size: 10px;"><i><?php esc_html(_e( 'If checked, voting result will show.', 'pm-suggestion-box' )); ?></i></span>
		</div>	
	<?php pm_sbox_votes_columns_content('pm_sbox_user_votes', $post->ID); ?>
	</div>
	<?php
}

add_action( 'save_post', 'pm_sbox_save_postdata' );
function pm_sbox_save_postdata( $post_id ) {
	$allow_auto_end = (get_option(PM_SBOX_SETTINGS_OPTION.'_auto_end') ? true : false);
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
	  return;
	if ( !empty( $_POST['pm_sbox_noncename'] ) && !wp_verify_nonce( $_POST['pm_sbox_noncename'], plugin_basename( __FILE__ ) ) )
	  return;
	if ( !empty($_POST['post_type']) && 'page' == $_POST['post_type'] ) 
	{
	if ( !current_user_can( 'edit_page', $post_id ) )
		return;
	}
	else
	{
	if ( !current_user_can( 'edit_post', $post_id ) )
		return;
	}
	if($allow_auto_end):
		$end_voting = (isset($_POST['_pm_end_voting']) ? esc_html($_POST['_pm_end_voting']) : '');
		$end_voting_result = (isset($_POST['_pm_end_voting_result']) ? esc_html($_POST['_pm_end_voting_result']) : '');
		$end_type = (isset($_POST['_pm_end_type']) ? esc_html($_POST['_pm_end_type']) : '');
		if($end_type == 'date'){
			$end_date = (isset($_POST['_pm_sbox_end_date']) ? esc_html($_POST['_pm_sbox_end_date']) : '');
			update_post_meta( $post_id, '_pm_sbox_end_date', $end_date);
		} elseif($end_type == 'total_vote') {
			$end_total_vote = (isset($_POST['_pm_sbox_end_total_vote']) ? absint($_POST['_pm_sbox_end_total_vote']) : '');
			update_post_meta( $post_id, '_pm_sbox_end_total_vote', $end_total_vote);
		}
		update_post_meta( $post_id, '_pm_end_voting', $end_voting);
		update_post_meta( $post_id, '_pm_end_type', $end_type);
		update_post_meta( $post_id, '_pm_end_voting_result', $end_voting_result);
	endif;
}

?>