<?php 
/* 
	*Flush rewrite rules for plugins. 
*/
register_deactivation_hook( __FILE__, 'flush_rewrite_rules' );
register_activation_hook( __FILE__, 'pm_sbox_flush_rewrites' );
function pm_sbox_flush_rewrites() {
	// call your CPT registration function here (it should also be hooked into 'init')
	pm_sbox_post_type_init();
	flush_rewrite_rules();
}
add_action( 'after_switch_theme', 'pm_sbox_flush_rewrites' );

/* References
 * https://github.com/chipbennett/oenology/blob/master/functions/options.php#L84
 * http://www.chipbennett.net/2011/02/17/incorporating-the-settings-api-in-wordpress-themes/7/
 */
 
add_action( 'admin_menu', 'pm_sbox_register_menu_page' );


function pm_sbox_register_menu_page() {
	
	//add_menu_page(esc_html(sprintf(__( '%s ', 'pm-suggestion-box' ), PM_SBOX_PLUGIN_NAME)), esc_html(sprintf(__( '%s Settings', 'pm-suggestion-box' ), PM_SBOX_PLUGIN_NAME)), 'manage_options', 'pm_sbox_settings', 'pm_sbox_settings_page', '', 22 );

	add_submenu_page('edit.php?post_type=suggestion_box', esc_html(sprintf(__( '%s ', 'pm-suggestion-box' ), PM_SBOX_PLUGIN_NAME)), esc_html(__( 'Settings', 'pm-suggestion-box' )), 'manage_options', 'pm_sbox_settings','pm_sbox_settings_page');

	add_action( 'admin_init', 'pm_sbox_settings_register_callback' );
}

/*
	* pm_sbox_settings_register_callback
*/

function pm_sbox_settings_register_callback() {
	$color_array = pm_sbox_color_picker_input();
	//register our settings
	register_setting( 'pm-suggestion-box-settings-group', PM_SBOX_SETTINGS_OPTION.'_new_suggestion_status');
	register_setting( 'pm-suggestion-box-settings-group', PM_SBOX_SETTINGS_OPTION.'_auto_end');
	register_setting( 'pm-suggestion-box-settings-group', PM_SBOX_SETTINGS_OPTION.'_public_create');
	register_setting( 'pm-suggestion-box-settings-group', PM_SBOX_SETTINGS_OPTION.'_guest');
	register_setting( 'pm-suggestion-box-settings-group', PM_SBOX_SETTINGS_OPTION.'_limit_day');
	foreach($color_array as $ckey => $color):
	register_setting( 'pm-suggestion-box-settings-group', PM_SBOX_SETTINGS_OPTION.$ckey);
	endforeach;
}

/*
	* pm_sbox_adminscripts
	* Enq Scripts and StyleSheets
	* FontAwesome: //maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css

*/

function pm_sbox_adminscripts() {
	wp_enqueue_script( 'jquery-ui-datepicker' );
	wp_enqueue_script( 'jquery-ui-autocomplete' );
	wp_register_style( 'pm-sbox-jquery-ui-styles', PM_SBOX_DIR.'modules/src/css/jquery-ui.datepicker.css', '', PM_SBOX_VERSION, 'all'  );
	wp_enqueue_style( 'pm-sbox-jquery-ui-styles' );
	wp_enqueue_script( 'pm-sbox-admin-livequery-script', PM_SBOX_DIR.'modules/libs/livequery/jquery.livequery.min.js', '', PM_SBOX_VERSION );
	wp_enqueue_style( 'wp-color-picker' );
	wp_enqueue_style( 'pm-sbox-admin-fa', '//maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css', '', PM_SBOX_VERSION, 'all' );
	wp_enqueue_script( 'pm-sbox-admin-chosen-script', PM_SBOX_DIR.'modules/libs/chosen/chosen.jquery.min.js', '', PM_SBOX_VERSION );
	wp_enqueue_style( 'pm-sbox-frontend-chosen-style', PM_SBOX_DIR.'modules/frontend/css/pm-sbox-style.css', '', PM_SBOX_VERSION, 'all' );
	wp_enqueue_style( 'pm-sbox-admin-chosen-style', PM_SBOX_DIR.'modules/libs/chosen/chosen.min.css', '', PM_SBOX_VERSION, 'all' );
	wp_enqueue_script( 'pm-sbox-admin-script', PM_SBOX_DIR.'modules/src/js/pm-sbox.js', array('jquery', 'wp-color-picker'), PM_SBOX_VERSION, true );
	
}
add_action( 'admin_init', 'pm_sbox_adminscripts' );
/*
	* pm_sbox_settings_page
*/

function pm_sbox_settings_page() { 
	$allow_auto_end = (get_option(PM_SBOX_SETTINGS_OPTION.'_auto_end') ? true : false);
	$allow_front_create = (get_option(PM_SBOX_SETTINGS_OPTION.'_public_create') ? true : false);
	$allow_guest = (get_option(PM_SBOX_SETTINGS_OPTION.'_guest') ? true : false);
	$limit_day = get_option(PM_SBOX_SETTINGS_OPTION.'_limit_day');
	$new_suggestion_status = get_option(PM_SBOX_SETTINGS_OPTION.'_new_suggestion_status');
	$color_array = pm_sbox_color_picker_input();
?>
	<div class="wrap">
		<h2><?php esc_html(printf(__( '%s Settings', 'pm-suggestion-box' ), PM_SBOX_PLUGIN_NAME)); ?></h2>
		<form method="post" class="pm_suggestion_box_form" action="options.php"> 
			<?php settings_fields( 'pm-suggestion-box-settings-group' ); ?>
			<?php do_settings_sections( 'pm-suggestion-box-settings-group' ); ?>
			<fieldset>
				<legend><?php esc_html(_e( 'Shortcode for Suggestion List', 'pm-suggestion-box' )); ?></legend>
				<p>[pm-suggestions limit="10"]</p>
				<p class="description"><?php _e( 'Place this shortcode to any Page or Post to Show the Suggestion List, or use the buttons in the visual editor.', 'pm-suggestion-box' ); ?></p>
			</fieldset>
			<fieldset>
				<legend><?php esc_html(_e( 'Shortcode to Create Suggestion Form', 'pm-suggestion-box' )); ?></legend>
				<p>[pm-suggestions-create]</p>
				<p class="description"><?php esc_html(_e( 'Place this shortcode to any Page or Post to Show the Suggestion List, or use the buttons in the visual editor.', 'pm-suggestion-box' )); ?></p>
			</fieldset>
			<fieldset>
				<legend><?php esc_html(_e( 'Plugin Settings', 'pm-suggestion-box' )); ?></legend>
				<div>
					<input <?php print ($allow_guest ? 'checked' : ''); ?> type="checkbox" name="<?php print PM_SBOX_SETTINGS_OPTION; ?>_guest" id="<?php print PM_SBOX_SETTINGS_OPTION; ?>_guest" class="" />
					<label for="<?php print PM_SBOX_SETTINGS_OPTION; ?>_guest"><?php esc_html(_e( 'Allow Public Voting', 'pm-suggestion-box' )); ?></label>
					<p class="description"><?php esc_html(_e( 'Check this if you want guest to be able to Vote. Will use Guest IP Address', 'pm-suggestion-box' )); ?></p>
				</div>
				<div>
					<input <?php print ($allow_front_create ? 'checked' : ''); ?> type="checkbox" name="<?php print PM_SBOX_SETTINGS_OPTION; ?>_public_create" id="<?php print PM_SBOX_SETTINGS_OPTION; ?>_public_create" class="" />
					<label for="<?php print PM_SBOX_SETTINGS_OPTION; ?>_public_create"><?php esc_html(_e( 'Allow Public Submission', 'pm-suggestion-box' )); ?></label>
					<p class="description"><?php esc_html(_e( 'Check if you want to enable front-end submission.', 'pm-suggestion-box' )); ?></p>
				</div>
				<div>
					<input <?php print ($allow_auto_end ? 'checked' : ''); ?> type="checkbox" name="<?php print PM_SBOX_SETTINGS_OPTION; ?>_auto_end" id="<?php print PM_SBOX_SETTINGS_OPTION; ?>_auto_end" class="" />
					<label for="<?php print PM_SBOX_SETTINGS_OPTION; ?>_auto_end"><?php esc_html(_e( 'Suggestion Auto Close', 'pm-suggestion-box' )); ?></label>
					<p class="description"><span><?php esc_html(_e( 'If checked,There will be an option to end each Suggestion when you Create. ', 'pm-suggestion-box' )); ?></span><br />
					<?php esc_html(_e( 'If disabled, All Suggestions will have no End even if they have auto end settings before.', 'pm-suggestion-box' )); ?></p>
				</div>
				
				<div>
					<label for="<?php print PM_SBOX_SETTINGS_OPTION; ?>_new_suggestion_status"><?php esc_html(_e( 'Status for new Suggestions', 'pm-suggestion-box' )); ?></label>
					<select name="<?php print PM_SBOX_SETTINGS_OPTION; ?>_new_suggestion_status" id="<?php print PM_SBOX_SETTINGS_OPTION; ?>_new_suggestion_status">
						<option <?php print ($new_suggestion_status == 'draft' ? 'selected' : ''); ?> value="draft"><?php esc_html(_e( 'Draft', 'pm-suggestion-box' )); ?></option>
						<option <?php print ($new_suggestion_status == 'publish' ? 'selected' : ''); ?> value="publish"><?php esc_html(_e( 'Publish', 'pm-suggestion-box' )); ?></option>
					</select>
					<p class="description"><?php esc_html(_e( 'Post Status for new created suggestions.', 'pm-suggestion-box' )); ?></p>
				</div>
				<?php /* ?>
				<div>
					<label for="<?php print PM_SBOX_SETTINGS_OPTION; ?>_limit_day"><?php esc_html(_e( 'Voting Limit per day', 'pm-suggestion-box' )); ?></label>
					<input type="number" name="<?php print PM_SBOX_SETTINGS_OPTION; ?>_limit_day" id="<?php print PM_SBOX_SETTINGS_OPTION; ?>_limit_day" class="" value="<?php print $limit_day; ?>" />
					<p class="description"><?php esc_html(_e( 'Add a limit for voting per day.', 'pm-suggestion-box' )); ?></p>
				</div>
				<?php */ ?>
			</fieldset>
			<fieldset>
				<legend><?php esc_html(_e( 'Styling', 'pm-suggestion-box' )); ?></legend>
				<?php foreach($color_array as $ckey => $color): ?>
				<div>
					<label for="<?php print PM_SBOX_SETTINGS_OPTION.$ckey; ?>"><?php esc_html(printf(__( '%s ', 'pm-suggestion-box' ), $color['label'])); ?></label>
					<input data-default-color="<?php print $color['val']; ?>" value="<?php print $color['val']; ?>" type="text" name="<?php print PM_SBOX_SETTINGS_OPTION.$ckey; ?>" id="<?php print PM_SBOX_SETTINGS_OPTION.$ckey; ?>" class="pm_sbox_color_picker" /><br />
				</div>
				<?php endforeach; ?>
			</fieldset>
			<?php submit_button(); ?>
		</form>	
	</div>
<?php
}



